log

package
v0.23.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 10, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Debug

func Debug(ctx context.Context, format string, args ...any)

Debug outputs an DEBUG-level log message to the logger configured in the supplied context.

func Info

func Info(ctx context.Context, format string, args ...any)

Info outputs an INFO-level log message to the logger configured in the supplied context.

func Warn

func Warn(ctx context.Context, format string, args ...any)

Warn outputs an WARN-level log message to the logger configured in the supplied context.

Types

This section is empty.

Jump to